chaincode

package
v0.0.0-...-32bd247 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 30, 2020 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Asset

type Asset struct {
	ID             string `json:"ID"`
	Color          string `json:"color"`
	Size           int    `json:"size"`
	Owner          string `json:"owner"`
	AppraisedValue int    `json:"appraisedValue"`
}

Asset describes basic details of what makes up a simple asset

type Asset2

type Asset2 struct {
	ID             string `json:"ID"`
	Color          string `json:"color"`
	Size           int    `json:"size"`
	Owner          string `json:"owner"`
	AppraisedValue int    `json:"appraisedValue"`
}

Asset2 sample asset for transfer

type SmartContract

type SmartContract struct {
	contractapi.Contract
}

SmartContract provides functions for managing an Asset

func (*SmartContract) AssetExists

AssetExists returns true when asset with given ID exists in world state

func (*SmartContract) CreateAsset

func (s *SmartContract) CreateAsset(ctx contractapi.TransactionContextInterface, id string, color string, size int, owner string, appraisedValue int) error

CreateAsset issues a new asset to the world state with given details.

func (*SmartContract) DeleteAsset

DeleteAsset deletes an given asset from the world state.

func (*SmartContract) GetAllAssets

GetAllAssets returns all assets found in world state

func (*SmartContract) InitLedger

InitLedger adds a base set of assets to the ledger

func (*SmartContract) ReadAsset

ReadAsset returns the asset stored in the world state with given id.

func (*SmartContract) TransferAsset

func (s *SmartContract) TransferAsset(ctx contractapi.TransactionContextInterface, id string, newOwner string) error

TransferAsset updates the owner field of asset with given id in world state.

func (*SmartContract) UpdateAsset

func (s *SmartContract) UpdateAsset(ctx contractapi.TransactionContextInterface, id string, color string, size int, owner string, appraisedValue int) error

UpdateAsset updates an existing asset in the world state with provided parameters.

type SmartContract2

type SmartContract2 struct {
	contractapi.Contract
}

SmartContract2 provides functions for managing an Asset

func (*SmartContract2) AssetExists

AssetExists returns true when asset with given ID exists in world state

func (*SmartContract2) CreateAsset

func (s *SmartContract2) CreateAsset(ctx contractapi.TransactionContextInterface, id string, color string, size int, owner string, appraisedValue int) error

CreateAsset issues a new asset to the world state with given details.

Jump to